==> gottet_1.1.9.orig.tar.gz: gottet-1.1.9/translations/gottet_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Întrebare</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Termină jocul curent?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;În pauză&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Clic pentru a relua jocul.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Joc terminat!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Clic pentru a începe un joc nou.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selectaţi limba aplicaţiei</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Limbaj sistem&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Notă</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Vă rugăm reporniţi această aplicaţie pentru ca schimbarea limbii să aibă efect.</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Gottet Scores</source>
        <translation>Scoruri Gottet</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Nivel</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Linii</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Scor</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Bine</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Clic pentru a începe joc nou.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Joc</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nou</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauză</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>&amp;Reluare</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Scoruri</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ieşire</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Setări</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Limbă aplicaţie...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajutor</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Despre</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Despre &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Piesa următoare</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Nivel</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Linii eliminate</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Scor</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Despre</translation>
    </message>
    <message>
        <source>A tetris clone I made for my wife</source>
        <translation>O clonă Tetris pe care am făcut-o pentru soţia mea</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Toate drepturile rezervate &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Lansat sub licenţă &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> gottet_1.2.4.orig.tar.gz: gottet-1.2.4/translations/gottet_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Întrebare</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Termină jocul curent?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;În pauză&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Clic pentru a relua jocul.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Joc terminat!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Clic pentru a începe un joc nou.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selectaţi limba aplicaţiei</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Limbaj sistem&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Notă</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Vă rugăm reporniţi această aplicaţie pentru ca schimbarea limbii să aibă efect.</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Level</source>
        <translation>Nivel</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Linii</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Scor</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation>Cele mai mari scoruri</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation>Rang</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nume</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Felicitări!</translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation>Ţi-ai învins cel mai bun scor!</translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation>Bravo!</translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation>Ai un nou scor mare!</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Clic pentru a începe joc nou.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Joc</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nou</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauză</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Scoruri</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ieşire</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Setări</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Limbă aplicaţie...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajutor</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Despre</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Despre &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Piesa următoare</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Nivel</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Linii eliminate</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Scor</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Despre</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Toate drepturile rezervate &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Lansat sub licenţă &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>A simple falling blocks game</source>
        <translation>Un joc simplu de blocuri care cad</translation>
    </message>
</context>
</TS>
